/*
 * ART
 *
 * Copyright 2019-2022 ART
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.art.logging.stream;

import io.art.logging.logger.*;
import lombok.*;
import static io.art.core.checker.EmptinessChecker.*;
import static io.art.core.constants.StringConstants.*;
import java.io.*;
import java.util.function.*;

@AllArgsConstructor
public class LoggerOutputStream extends ByteArrayOutputStream {
    private final Logger logger;
    private final BiConsumer<Logger, String> writer;

    @Override
    public void flush() {
        String message = toString();
        reset();
        if (isEmpty(message.trim().replaceAll(SPACE, EMPTY_STRING))) return;
        writer.accept(logger, message);
    }
}
